@@ -37,6 +37,7 @@ import os  # shouldn't have to list any folder in the future!
 import json
 import cherrypy
 import codecs
+import re
 import sys
 
 try:
@@ -382,11 +383,12 @@ class HTTPHandler(object):
         else:
             return "error: not permitted. Only admins can change other users options"
 
-    def api_fetchalbumarturls(self, searchterm):
+    def api_fetchalbumarturls(self, searchterm, method=None):
         if not cherrypy.session['admin']:
             raise cherrypy.HTTPError(401, 'Unauthorized')
         _save_and_release_session()
-        fetcher = albumartfetcher.AlbumArtFetcher()
+        fetch_args = {} if method is None else {'method': method}
+        fetcher = albumartfetcher.AlbumArtFetcher(**fetch_args)
         imgurls = fetcher.fetchurls(searchterm)
         # show no more than 10 images
         return imgurls[:min(len(imgurls), 10)]
@@ -439,10 +441,26 @@ class HTTPHandler(object):
             cherrypy.response.headers.update(header)
             return data
         elif cherry.config['media.fetch_album_art']:
+            # maximum of files to try to fetch metadata for albumart keywords
+            METADATA_ALBUMART_MAX_FILES = 10
             #fetch album art from online source
             try:
                 foldername = os.path.basename(directory)
                 keywords = foldername
+                # remove any odd characters from the folder name
+                keywords = re.sub('[^A-Za-z\s]', ' ', keywords)
+                # try getting metadata from files in the folder for a more
+                # accurate match
+                files = os.listdir(localpath)
+                for i, filename in enumerate(files):
+                    if i >= METADATA_ALBUMART_MAX_FILES:
+                        break
+                    path = os.path.join(localpath, filename)
+                    metadata = metainfo.getSongInfo(path)
+                    if metadata.artist and metadata.album:
+                        keywords = '{} - {}'.format(metadata.artist, metadata.album)
+                        break
+
                 log.i(_("Fetching album art for keywords {keywords!r}").format(keywords=keywords))
                 header, data = fetcher.fetch(keywords)
                 if header:
@@ -718,7 +736,10 @@ class HTTPHandler(object):
             'servepath': 'serve/',
             'transcodepath': 'trans/',
             'auto_login': self.autoLoginActive(),
+            'rootpath': cherry.config['server.rootpath'],
             'version': cherry.REPO_VERSION or cherry.VERSION,
+            'albumart_search_methods': list(
+                albumartfetcher.AlbumArtFetcher.methods),
         }
         if cherry.config['media.transcode']:
             decoders = list(self.model.transcoder.available_decoder_formats())
